@@ -1,6 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008, 2009, 2010 by Malakhov Alexey                           *
- *   brezerk@gmail.com                                                     *
+ *   Copyright (C) 2008-2025 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,89 +19,95 @@
 #ifndef LOGGINGWIDGET_H
 #define LOGGINGWIDGET_H
 
-//System
+// System
 #include <memory>
 
-//Global config
-#include "config.h"
-
-#include <QWidget>
-#include <QToolBar>
+// Global config
 #include <QAction>
+#include <QBrush>
+#include <QClipboard>
+#include <QDateTime>
+#include <QKeyEvent>
+#include <QLineEdit>
+#include <QListWidget>
+#include <QMenu>
+#include <QPalette>
+#include <QPushButton>
+#include <QSplitter>
+#include <QToolBar>
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
-#include <QListWidget>
-#include <QSplitter>
-#include <QLineEdit>
-#include <QDateTime>
-#include <QBrush>
-#include <QPalette>
-#include <QMenu>
-#include <QKeyEvent>
-#include <QClipboard>
+#include <QWidget>
 
+#include "config.h"
 #include "logging.h"
 #include "prefix.h"
 
-//q4wine lib
+// q4wine lib
 #include "q4wine-lib.h"
 
-class LoggingWidget : public QWidget
-{
-Q_OBJECT
-public:
-    explicit LoggingWidget(QWidget *parent = 0);
-    ~LoggingWidget();
+#define D_LOGGING_DISABLED 0
+#define D_LOGGING_ENABLED 1
 
+class LoggingWidget : public QWidget {
+  Q_OBJECT
+ public:
+  explicit LoggingWidget(QWidget *parent = nullptr);
+  ~LoggingWidget();
 
-signals:
+ signals:
 
-public slots:
-    void getLogRecords(void);
+ public slots:
+  void getLogRecords(void);
 
-private slots:
-    void logClear_Click(void);
-    void logDelete_Click(void);
-    void logExport_Click(void);
+ private slots:
+  void logClear_Click(void);
+  void logDelete_Click(void);
+  void logExport_Click(void);
+  void logEnable_Click(void);
 
-    void logCopy_Click(void);
-    void logSelectAll_Click(void);
+  void logCopy_Click(void);
+  void logSelectAll_Click(void);
 
-    void treeWidget_itemClicked (QTreeWidgetItem * item, int colum);
-    void treeWidget_currentItemChanged (QTreeWidgetItem *item, QTreeWidgetItem *);
+  void treeWidget_itemClicked(QTreeWidgetItem *item, int column);
+  void treeWidget_currentItemChanged(QTreeWidgetItem *item, QTreeWidgetItem *);
 
-    void treeWidget_customContextMenuRequested(const QPoint &pos);
-    void listWidget_customContextMenuRequested(const QPoint &pos);
+  void treeWidget_customContextMenuRequested(const QPoint &pos);
+  void listWidget_customContextMenuRequested(const QPoint &pos);
 
-private:
-    //! This is need for libq4wine-core.so import.
-    QLibrary libq4wine;
-    typedef void *CoreLibPrototype (bool);
-    CoreLibPrototype *CoreLibClassPointer;
-    std::auto_ptr<corelib> CoreLib;
+ private:
+  //! This is need for libq4wine-core.so import.
+  QLibrary libq4wine;
+  typedef void *CoreLibPrototype(bool);
+  CoreLibPrototype *CoreLibClassPointer;
+  std::unique_ptr<corelib> CoreLib;
 
-    Logging db_log;
-    Prefix db_prefix;
+  Logging db_log;
+  Prefix db_prefix;
 
-    std::auto_ptr<QAction> logClear;
-    std::auto_ptr<QAction> logDelete;
-    std::auto_ptr<QAction> logExport;
+  std::unique_ptr<QAction> logClear;
+  std::unique_ptr<QAction> logDelete;
+  std::unique_ptr<QAction> logExport;
 
-    std::auto_ptr<QAction> logSelectAll;
-    std::auto_ptr<QAction> logCopy;
+  std::unique_ptr<QAction> logSelectAll;
+  std::unique_ptr<QAction> logCopy;
 
-    std::auto_ptr<QTreeWidget> treeWidget;
-    std::auto_ptr<QListWidget> listWidget;
-    std::auto_ptr<QSplitter> splitter;
+  std::unique_ptr<QAction> logEnable;
+  std::unique_ptr<QLabel> logStatus;
 
-    //std::auto_ptr<QMenu> menu;
+  int log_status;
 
-    void createActions(void);
-    void clearLogs(void);
+  std::unique_ptr<QTreeWidget> treeWidget;
+  std::unique_ptr<QListWidget> listWidget;
+  std::unique_ptr<QSplitter> splitter;
 
-protected:
-    bool eventFilter(QObject *obj, QEvent *ev);
+  // std::unique_ptr<QMenu> menu;
 
+  void createActions(void);
+  void clearLogs(void);
+
+ protected:
+  bool eventFilter(QObject *obj, QEvent *ev);
 };
 
-#endif // LOGGINGWIDGET_H
+#endif  // LOGGINGWIDGET_H
